==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/KubernetesPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.KubernetesPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Kubernetes properties
 * @property defaultInstanceType Default instance type
 * @property extensionInstanceReleaseTrain Extension instance release train.
 * @property extensionPrincipalId Extension principal-id.
 * @property instanceTypes Instance Type Schema
 * @property namespace Compute namespace
 * @property relayConnectionString Relay connection string.
 * @property serviceBusConnectionString ServiceBus connection string.
 * @property vcName VC name.
 */
public data class KubernetesPropertiesArgs(
    public val defaultInstanceType: Output<String>? = null,
    public val extensionInstanceReleaseTrain: Output<String>? = null,
    public val extensionPrincipalId: Output<String>? = null,
    public val instanceTypes: Output<Map<String, InstanceTypeSchemaArgs>>? = null,
    public val namespace: Output<String>? = null,
    public val relayConnectionString: Output<String>? = null,
    public val serviceBusConnectionString: Output<String>? = null,
    public val vcName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.KubernetesPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.KubernetesPropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.KubernetesPropertiesArgs.builder()
            .defaultInstanceType(defaultInstanceType?.applyValue({ args0 -> args0 }))
            .extensionInstanceReleaseTrain(extensionInstanceReleaseTrain?.applyValue({ args0 -> args0 }))
            .extensionPrincipalId(extensionPrincipalId?.applyValue({ args0 -> args0 }))
            .instanceTypes(
                instanceTypes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value.let({ args0 -> args0.toJava() }))
                    }).toMap()
                }),
            )
            .namespace(namespace?.applyValue({ args0 -> args0 }))
            .relayConnectionString(relayConnectionString?.applyValue({ args0 -> args0 }))
            .serviceBusConnectionString(serviceBusConnectionString?.applyValue({ args0 -> args0 }))
            .vcName(vcName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KubernetesPropertiesArgs].
 */
@PulumiTagMarker
public class KubernetesPropertiesArgsBuilder internal constructor() {
    private var defaultInstanceType: Output<String>? = null

    private var extensionInstanceReleaseTrain: Output<String>? = null

    private var extensionPrincipalId: Output<String>? = null

    private var instanceTypes: Output<Map<String, InstanceTypeSchemaArgs>>? = null

    private var namespace: Output<String>? = null

    private var relayConnectionString: Output<String>? = null

    private var serviceBusConnectionString: Output<String>? = null

    private var vcName: Output<String>? = null

    /**
     * @param value Default instance type
     */
    @JvmName("thcqgkpcrlmbvatg")
    public suspend fun defaultInstanceType(`value`: Output<String>) {
        this.defaultInstanceType = value
    }

    /**
     * @param value Extension instance release train.
     */
    @JvmName("vsydpeeslmfkjica")
    public suspend fun extensionInstanceReleaseTrain(`value`: Output<String>) {
        this.extensionInstanceReleaseTrain = value
    }

    /**
     * @param value Extension principal-id.
     */
    @JvmName("mbghlvdtihoiccdc")
    public suspend fun extensionPrincipalId(`value`: Output<String>) {
        this.extensionPrincipalId = value
    }

    /**
     * @param value Instance Type Schema
     */
    @JvmName("mrmkjqpwysojujxi")
    public suspend fun instanceTypes(`value`: Output<Map<String, InstanceTypeSchemaArgs>>) {
        this.instanceTypes = value
    }

    /**
     * @param value Compute namespace
     */
    @JvmName("fafhbtfbtmvbucss")
    public suspend fun namespace(`value`: Output<String>) {
        this.namespace = value
    }

    /**
     * @param value Relay connection string.
     */
    @JvmName("slxwnlkeiidfgupp")
    public suspend fun relayConnectionString(`value`: Output<String>) {
        this.relayConnectionString = value
    }

    /**
     * @param value ServiceBus connection string.
     */
    @JvmName("hwfbtwxtqainkkgd")
    public suspend fun serviceBusConnectionString(`value`: Output<String>) {
        this.serviceBusConnectionString = value
    }

    /**
     * @param value VC name.
     */
    @JvmName("jxkhsolkqwbisvjx")
    public suspend fun vcName(`value`: Output<String>) {
        this.vcName = value
    }

    /**
     * @param value Default instance type
     */
    @JvmName("otbnbqorovduohur")
    public suspend fun defaultInstanceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultInstanceType = mapped
    }

    /**
     * @param value Extension instance release train.
     */
    @JvmName("ihcjprvlgcjhqxqa")
    public suspend fun extensionInstanceReleaseTrain(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extensionInstanceReleaseTrain = mapped
    }

    /**
     * @param value Extension principal-id.
     */
    @JvmName("vqwhloajiqvnykmm")
    public suspend fun extensionPrincipalId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extensionPrincipalId = mapped
    }

    /**
     * @param value Instance Type Schema
     */
    @JvmName("fsdekbfdmwtufxky")
    public suspend fun instanceTypes(`value`: Map<String, InstanceTypeSchemaArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.instanceTypes = mapped
    }

    /**
     * @param argument Instance Type Schema
     */
    @JvmName("temprommbwccmqia")
    public suspend fun instanceTypes(
        vararg
        argument: Pair<String, suspend InstanceTypeSchemaArgsBuilder.() -> Unit>,
    ) {
        val toBeMapped = argument.toList().map { (left, right) ->
            left to
                InstanceTypeSchemaArgsBuilder().applySuspend { right() }.build()
        }.toMap()
        val mapped = of(toBeMapped)
        this.instanceTypes = mapped
    }

    /**
     * @param values Instance Type Schema
     */
    @JvmName("bhrrpfbxqrpmahtw")
    public fun instanceTypes(vararg values: Pair<String, InstanceTypeSchemaArgs>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceTypes = mapped
    }

    /**
     * @param value Compute namespace
     */
    @JvmName("nxeygrqguilkkano")
    public suspend fun namespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespace = mapped
    }

    /**
     * @param value Relay connection string.
     */
    @JvmName("nkbrjlyhnvdnyooh")
    public suspend fun relayConnectionString(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.relayConnectionString = mapped
    }

    /**
     * @param value ServiceBus connection string.
     */
    @JvmName("jgrkqpokvsvtekch")
    public suspend fun serviceBusConnectionString(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceBusConnectionString = mapped
    }

    /**
     * @param value VC name.
     */
    @JvmName("ehbxyaftqlssqrud")
    public suspend fun vcName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vcName = mapped
    }

    internal fun build(): KubernetesPropertiesArgs = KubernetesPropertiesArgs(
        defaultInstanceType = defaultInstanceType,
        extensionInstanceReleaseTrain = extensionInstanceReleaseTrain,
        extensionPrincipalId = extensionPrincipalId,
        instanceTypes = instanceTypes,
        namespace = namespace,
        relayConnectionString = relayConnectionString,
        serviceBusConnectionString = serviceBusConnectionString,
        vcName = vcName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/KubernetesPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.KubernetesPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Kubernetes properties
 * @property defaultInstanceType Default instance type
 * @property extensionInstanceReleaseTrain Extension instance release train.
 * @property extensionPrincipalId Extension principal-id.
 * @property instanceTypes Instance Type Schema
 * @property namespace Compute namespace
 * @property relayConnectionString Relay connection string.
 * @property serviceBusConnectionString ServiceBus connection string.
 * @property vcName VC name.
 */
public data class KubernetesPropertiesArgs(
    public val defaultInstanceType: Output<String>? = null,
    public val extensionInstanceReleaseTrain: Output<String>? = null,
    public val extensionPrincipalId: Output<String>? = null,
    public val instanceTypes: Output<Map<String, InstanceTypeSchemaArgs>>? = null,
    public val namespace: Output<String>? = null,
    public val relayConnectionString: Output<String>? = null,
    public val serviceBusConnectionString: Output<String>? = null,
    public val vcName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.KubernetesPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.KubernetesPropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.KubernetesPropertiesArgs.builder()
            .defaultInstanceType(defaultInstanceType?.applyValue({ args0 -> args0 }))
            .extensionInstanceReleaseTrain(extensionInstanceReleaseTrain?.applyValue({ args0 -> args0 }))
            .extensionPrincipalId(extensionPrincipalId?.applyValue({ args0 -> args0 }))
            .instanceTypes(
                instanceTypes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value.let({ args0 -> args0.toJava() }))
                    }).toMap()
                }),
            )
            .namespace(namespace?.applyValue({ args0 -> args0 }))
            .relayConnectionString(relayConnectionString?.applyValue({ args0 -> args0 }))
            .serviceBusConnectionString(serviceBusConnectionString?.applyValue({ args0 -> args0 }))
            .vcName(vcName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KubernetesPropertiesArgs].
 */
@PulumiTagMarker
public class KubernetesPropertiesArgsBuilder internal constructor() {
    private var defaultInstanceType: Output<String>? = null

    private var extensionInstanceReleaseTrain: Output<String>? = null

    private var extensionPrincipalId: Output<String>? = null

    private var instanceTypes: Output<Map<String, InstanceTypeSchemaArgs>>? = null

    private var namespace: Output<String>? = null

    private var relayConnectionString: Output<String>? = null

    private var serviceBusConnectionString: Output<String>? = null

    private var vcName: Output<String>? = null

    /**
     * @param value Default instance type
     */
    @JvmName("dyqpdlhkqrvqpiju")
    public suspend fun defaultInstanceType(`value`: Output<String>) {
        this.defaultInstanceType = value
    }

    /**
     * @param value Extension instance release train.
     */
    @JvmName("ljjnxykkbnlytjsg")
    public suspend fun extensionInstanceReleaseTrain(`value`: Output<String>) {
        this.extensionInstanceReleaseTrain = value
    }

    /**
     * @param value Extension principal-id.
     */
    @JvmName("yaxkewaibfpeytko")
    public suspend fun extensionPrincipalId(`value`: Output<String>) {
        this.extensionPrincipalId = value
    }

    /**
     * @param value Instance Type Schema
     */
    @JvmName("qbwatvmxxqqcpwwx")
    public suspend fun instanceTypes(`value`: Output<Map<String, InstanceTypeSchemaArgs>>) {
        this.instanceTypes = value
    }

    /**
     * @param value Compute namespace
     */
    @JvmName("giiydqhxasagdeip")
    public suspend fun namespace(`value`: Output<String>) {
        this.namespace = value
    }

    /**
     * @param value Relay connection string.
     */
    @JvmName("spolrcdxdsjkaxnf")
    public suspend fun relayConnectionString(`value`: Output<String>) {
        this.relayConnectionString = value
    }

    /**
     * @param value ServiceBus connection string.
     */
    @JvmName("jcbcbwpkhklvidqy")
    public suspend fun serviceBusConnectionString(`value`: Output<String>) {
        this.serviceBusConnectionString = value
    }

    /**
     * @param value VC name.
     */
    @JvmName("hxhwblxwjrmrcnuy")
    public suspend fun vcName(`value`: Output<String>) {
        this.vcName = value
    }

    /**
     * @param value Default instance type
     */
    @JvmName("tytqjqvmvrdabgei")
    public suspend fun defaultInstanceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultInstanceType = mapped
    }

    /**
     * @param value Extension instance release train.
     */
    @JvmName("rbgnrsvdoqguhisw")
    public suspend fun extensionInstanceReleaseTrain(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extensionInstanceReleaseTrain = mapped
    }

    /**
     * @param value Extension principal-id.
     */
    @JvmName("qvbyxglvwqboevev")
    public suspend fun extensionPrincipalId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extensionPrincipalId = mapped
    }

    /**
     * @param value Instance Type Schema
     */
    @JvmName("tucuqylsoygjmkyg")
    public suspend fun instanceTypes(`value`: Map<String, InstanceTypeSchemaArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.instanceTypes = mapped
    }

    /**
     * @param argument Instance Type Schema
     */
    @JvmName("jkufulxxgeysvtks")
    public suspend fun instanceTypes(
        vararg
        argument: Pair<String, suspend InstanceTypeSchemaArgsBuilder.() -> Unit>,
    ) {
        val toBeMapped = argument.toList().map { (left, right) ->
            left to
                InstanceTypeSchemaArgsBuilder().applySuspend { right() }.build()
        }.toMap()
        val mapped = of(toBeMapped)
        this.instanceTypes = mapped
    }

    /**
     * @param values Instance Type Schema
     */
    @JvmName("wbjnitkwwfveprux")
    public fun instanceTypes(vararg values: Pair<String, InstanceTypeSchemaArgs>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceTypes = mapped
    }

    /**
     * @param value Compute namespace
     */
    @JvmName("txgkumktnsiecamr")
    public suspend fun namespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespace = mapped
    }

    /**
     * @param value Relay connection string.
     */
    @JvmName("clgyyothocnmefhp")
    public suspend fun relayConnectionString(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.relayConnectionString = mapped
    }

    /**
     * @param value ServiceBus connection string.
     */
    @JvmName("aemninkthiebyarw")
    public suspend fun serviceBusConnectionString(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceBusConnectionString = mapped
    }

    /**
     * @param value VC name.
     */
    @JvmName("dctycfygonkbmnnl")
    public suspend fun vcName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vcName = mapped
    }

    internal fun build(): KubernetesPropertiesArgs = KubernetesPropertiesArgs(
        defaultInstanceType = defaultInstanceType,
        extensionInstanceReleaseTrain = extensionInstanceReleaseTrain,
        extensionPrincipalId = extensionPrincipalId,
        instanceTypes = instanceTypes,
        namespace = namespace,
        relayConnectionString = relayConnectionString,
        serviceBusConnectionString = serviceBusConnectionString,
        vcName = vcName,
    )
}
